Module: GitHubEventWatcher

Defined in:
lib/github-event-watcher/event.rb,
lib/github-event-watcher/version.rb,
lib/github-event-watcher/watcher.rb,
lib/github-event-watcher/webhook-sender.rb,
lib/github-event-watcher/persistent-state.rb,
lib/github-event-watcher/command/github-pull-push-events.rb

Overview

Copyright © 2014 Kouhei Sutou <[email protected]>

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <www.gnu.org/licenses/>.

Defined Under Namespace

Modules: Command Classes: Event, PersistentState, Watcher, WebhookSender

Constant Summary collapse

VERSION =
"1.0.0"